@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::PluginBundle::NGLENN;
 # ABSTRACT: Dist::Zilla plugin configuration for me
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Dependencies
 use Moose 0.99;
@@ -431,10 +431,10 @@ sub configure {
                             allow_dirty_match => '^lib|^bin',
                         )
                     },
-                    'Git::Tag' => { tag_format => $self->tag_format }
+                    'Git::Tag' => { tag_format => $self->tag_format },
+                    'Git::Push' => { push_to => \@push_to },
+                    'GitHub::UploadRelease' => {}
                 ],
-                [ 'Git::Push' => { push_to => \@push_to } ],
-                'GitHub::UploadRelease'
             )
         )
 
@@ -468,7 +468,7 @@ Dist::Zilla::PluginBundle::NGLENN - Dist::Zilla plugin configuration for me
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
